@@ -22,6 +22,9 @@ class AuthConfig:
 class PlanConfig:
     """Test plan configuration."""
 
+    # Current config version
+    version = CONFIG_VERSION
+
     target_url: str = attr.ib(kw_only=True)
     spec_path: Optional[str] = attr.ib(kw_only=True, default=None)
     test_plan_path: Optional[str] = attr.ib(kw_only=True, default=None)
@@ -29,13 +32,16 @@ class PlanConfig:
     auth: Optional[Tuple[str, str]] = attr.ib(kw_only=True, default=None)
     auth_type: Optional[str] = attr.ib(kw_only=True, default=None)
     report_to_saas: bool = attr.ib(kw_only=True, default=True)
-    auth_config: AuthConfig = attr.ib(kw_only=True)
+    auth_config: Optional[AuthConfig] = attr.ib(kw_only=True, default=None)
     headers: Dict[str, str] = attr.ib(kw_only=True, factory=dict)
     env_file_path: Optional[str] = attr.ib(kw_only=True, default=None)
-    module_providers: Dict[Module, Provider] = attr.ib(kw_only=True, factory=dict)
-    # Current config version
-    version = CONFIG_VERSION
+    ignore_ssl_verify: bool = attr.ib(kw_only=True, default=False)
+    suite_execution_delay: int = attr.ib(kw_only=True, default=0)
 
+    # Module providers
+    module_providers: Dict[Module, Provider] = attr.ib(kw_only=True, factory=dict)
+
+    # Log handlers
     test_case_log_handler: Optional[Handler] = attr.ib(kw_only=True, default=None)
     runner_log_handler: Optional[Handler] = attr.ib(kw_only=True, default=None)
 
