@@ -514,6 +514,10 @@ class BeforeTestSuiteExecutionPayload(Payload):
     name: str = attr.ib()
     test_suite_id: Optional[str] = attr.ib(default=None)
     modules: List[str] = attr.ib(factory=list)
+    # This is the list of Auth headers for the test suite or endpoint that's being tested.
+    # This will enable the event consumers to treat the auth header(s) specially,
+    # like masking them or completely removing them from the reported results.
+    auth_headers: List[str] = attr.ib(factory=list)
 
 
 @attr.s(slots=True)
